Code contributors
-----------------

See [Github contributors list](https://github.com/nipy/nipype/graphs/contributors)

Special thanks
--------------

- Magdalena O. Cichocka
  - Testing and feedback on cRED implementation

- Jonas Ångström
  - Neural network implementation
  - Early scripts for data processing

- Wei Wan
  - DLLs for timepix/orius camera interface

Funding
-------

Development of `Instamatic` was supported by the Swiss National Science Foundation through the following projects:

- 2016-2017: [Development of serial crystallography methods for structure solution of polycrystalline materials using electron diffraction](http://p3.snf.ch/project-165282)
- 2018: [Development of serial electron crystallography methodology for quantitative phase analysis](http://p3.snf.ch/Project-177761)
